reactive library

Classes

AsyncData<T>
The state of an AsyncValue when the asynchronous operation has completed successfully.
AsyncError<T>
The state of an AsyncValue when the asynchronous operation has failed.
AsyncLoading<T>
The state of an AsyncValue when the asynchronous operation is in progress.
AsyncSignal<T>
Reactive state for a Future or Stream operation.
AsyncSignalFamily<T, Arg>
A caching registry that creates and manages a family of AsyncSignals based on arguments.
AsyncValue<T>
A sealed class representing the state of an asynchronous operation (such as a Future or Stream).
Computed<T>
A Computed value is a derived reactive value computed by a getter function.
ConsoleSignalObserver
A concrete SignalObserver that prints signal lifecycle events and changes to the console.
Effect
An Effect represents a side-effect function that automatically re-runs whenever any of the signals or computed values it accesses during execution change.
InMemorySignalStorage
A default in-memory implementation of SignalStorage used as a fallback.
Signal<T>
A Signal holds a single reactive value of type T.
SignalFamily<T, Arg>
A caching registry that creates and manages a family of Signals based on arguments.
SignalObserver
An abstract base class for monitoring and tracing all Signal lifecycles and changes.
SignalStorage
An interface for storing and retrieving persisted signal states.
SignalSubscription<T>
A cancellable subscription created by Signal.listen.

Properties

globalSignalStorage SignalStorage?
Global registry for the active SignalStorage.
getter/setter pair
signalObserver SignalObserver?
The global registry for the active SignalObserver.
getter/setter pair

Functions

batch(void fn()) → void
Batches multiple signal updates together so that dependent effects only run once after the batch function completes.
effect(void fn()) Effect
Helper function to create and run an Effect.
effectWithCleanup(void fn(void (void ()))) Effect
Creates an effect with per-run and disposal cleanup support.