notify method
Reloads when a reactive dependency used by the source changes.
Implementation
@override
void notify() {
unawaited(_start());
}
Reloads when a reactive dependency used by the source changes.
@override
void notify() {
unawaited(_start());
}