refresh method

Future<void> refresh()

Reloads the source and completes when a Future source settles.

For Stream sources this completes after the new subscription is created.

Implementation

Future<void> refresh() => _start();