Computed<T> constructor
Computed<T> (
- T _computeFn()
Creates a new Computed with the given computation function.
Implementation
Computed(this._computeFn);
Creates a new Computed with the given computation function.
Computed(this._computeFn);