ConsoleSignalObserver class
A concrete SignalObserver that prints signal lifecycle events and changes to the console.
- Inheritance
-
- Object
- SignalObserver
- ConsoleSignalObserver
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onSignalChanged(
Signal signal, Object? oldValue, Object? newValue) → void -
Called when a Signal's value is updated.
override
-
onSignalCreated(
Signal signal) → void -
Called when a Signal is created.
override
-
onSignalDisposed(
Signal signal) → void -
Called when a Signal is disposed.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited