Effect constructor
Effect(
- void _fn()?
Creates a new Effect and executes the given function immediately.
Implementation
Effect(this._fn) : _cleanupFn = null {
run();
}
Creates a new Effect and executes the given function immediately.
Effect(this._fn) : _cleanupFn = null {
run();
}