Effect.lazy constructor
Effect.lazy(
- void _fn()?
Creates a new Effect without executing the callback function immediately.
Implementation
Effect.lazy(this._fn) : _cleanupFn = null;
Creates a new Effect without executing the callback function immediately.
Effect.lazy(this._fn) : _cleanupFn = null;