InMemorySignalStorage class
A default in-memory implementation of SignalStorage used as a fallback.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String key) → void -
Removes the value associated with
keyfrom storage.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String key) → String? -
Reads the string value associated with
key, ornullif not found.override -
toString(
) → String -
A string representation of this object.
inherited
-
write(
String key, String value) → void -
Writes the string
valueassociated withkeyto storage.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited