autoDisposeEnabled property
Whether this signal should automatically dispose of its resources when it has no observers.
Implementation
bool autoDisposeEnabled;
Whether this signal should automatically dispose of its resources when it has no observers.
bool autoDisposeEnabled;