SignalScope constructor
Creates a SignalScope with the given overrides and a child widget.
Implementation
const SignalScope({
super.key,
required this.overrides,
required super.child,
});
Creates a SignalScope with the given overrides and a child widget.
const SignalScope({
super.key,
required this.overrides,
required super.child,
});