SignalSubscription<T> class

A cancellable subscription created by Signal.listen.

Constructors

SignalSubscription(Signal<T> signal, void _listener(T previous, T current), {bool fireImmediately = false})
Creates a subscription and attaches it to signal.

Properties

hashCode int
The hash code for this object.
no setterinherited
isCanceled bool
Whether this subscription has been canceled.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Stops listening. Calling this more than once is safe.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify() → void
Notifies the consumer that one of its dependencies has changed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited