refresh method
Reloads the source and completes when a Future source settles.
For Stream sources this completes after the new subscription is created.
Implementation
Future<void> refresh() => _start();
Reloads the source and completes when a Future source settles.
For Stream sources this completes after the new subscription is created.
Future<void> refresh() => _start();