FlutterSignalObserver class
A specialized observer that holds a WeakReference to a Flutter Element to trigger rebuilds on value change without causing memory leaks.
Constructors
- FlutterSignalObserver(_ElementWatchState _state, Node node)
-
Creates a new observer for the given
elementandnode.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDead → bool
-
Returns
trueif the referenced element has been garbage-collected or unmounted.no setter - node → Node
-
The node being observed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
) → void - Notifies the consumer that one of its dependencies has changed.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited