SignalObserver class abstract

An abstract base class for monitoring and tracing all Signal lifecycles and changes.

Subclass this and assign it to the global signalObserver to centrally monitor signal creations, mutations, and disposals.

Implementers

Constructors

SignalObserver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSignalChanged(Signal signal, Object? oldValue, Object? newValue) → void
Called when a Signal's value is updated.
onSignalCreated(Signal signal) → void
Called when a Signal is created.
onSignalDisposed(Signal signal) → void
Called when a Signal is disposed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

enableLogging() → void
Enables console logging observer globally.