batch function
void
batch(
- void fn()
Batches multiple signal updates together so that dependent effects only run once after the batch function completes.
Implementation
void batch(void Function() fn) {
startBatch();
try {
fn();
} finally {
endBatch();
}
}